{% load staticfiles %}

<div class="column-quarter">
    <ul class="ul-icon-list">
        <li>
            <i class="fa fa-info"></i> <a href="/about">About {{ WAZIMAP.name }}</a>
        </li>
        {% if WAZIMAP.twitter %}
        <li>
            <i class="fa fa-twitter"></i> <a href="http://twitter.com/{{ WAZIMAP.twitter }}" target="_blank">{{ WAZIMAP.twitter }}</a>
        </li>
        {% endif %}
    </ul>
</div>
<div class="column-quarter">
    <ul class="ul-icon-list">
        <li>
            <i class="fa fa-github"></i> <a href="https://github.com/Code4SA/wazimap" target="_blank">Wazimap on Github</a>
        </li>
        <li>
            <i class="fa fa-github"></i> Built on <a href="http://censusreporter.org" target="_blank">CensusReporter.org</a>
        </li>
    </ul>
</div>
<div class="column-quarter">
    <ul class="ul-icon-list">
        {% block footer_branding %}
        <li>
            <a href="http://www.mediamonitoringafrica.org/"><img class="mma-logo" src="{% static 'img/mma.png' %}"></a>
        </li>
        <li>
            <a href="http://www.code4sa.org/"><img src="{% static 'img/code4sa-logo-small.png' %}"></a>
        </li>
        {% endblock %}
    </ul>
</div>
